@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the Hooktheory API
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Moo;
 use strictures 2;
@@ -26,7 +26,7 @@ has password => (
 
 
 has activkey => (
-    is => 'rw',
+    is => 'ro',
 );
 
 
@@ -49,8 +49,9 @@ sub BUILD {
         );
 
         my $data = _handle_response($tx);
-        $self->activkey( $data->{activkey} )
-            if $data;
+
+        $self->{activkey} = $data->{activkey}
+            if $data && $data->{activkey};
     }
 }
 
@@ -114,7 +115,7 @@ WebService::Hooktheory - Access to the Hooktheory API
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
